import board  # Import board module to access pin names
import analogio# Import analogio to work with analog inputs/outputs
import digitalio
import time  # Import time module to handle delays
import usb_hid
from adafruit_hid.keyboard import Keyboard
from adafruit_hid.keycode import Keycode
from adafruit_hid.mouse import Mouse	

button = digitalio.DigitalInOut(board.D7)  # Define button on pin D7
button.direction = digitalio.Direction.INPUT  # Set as an input (reading data)
button.pull = digitalio.Pull.UP  # Enable internal pull-up resistor (default HIGH)

# Variable to track previous button state
previous_state = button.value  # Start by storing the initial button state

keyboard = Keyboard(usb_hid.devices)
mouse = Mouse(usb_hid.devices)

pot_x = analogio.AnalogIn(board.A0)
pot_y = analogio.AnalogIn(board.A1)
pot_z = analogio.AnalogIn(board.A2)

center = 65535 // 2 # The center of the pot
neutral_zone = 10000 # Area on pot where there is no input

while True:
    pot_value_x = pot_x.value
    deviation_x = pot_value_x - center

    pot_value_y = pot_y.value
    deviation_y = pot_value_y - center

    pot_value_z = pot_z.value
    deviation_z = pot_value_z - center
    
    current_state = button.value

    if previous_state and not current_state:
        keyboard.press(Keycode.HOME)
        keyboard.press(Keycode.SHIFT, Keycode.C)
    
    keyboard.release_all()
    
    previous_state = current_state

    print(pot_value_x)

    if abs(deviation_x) > neutral_zone: 
        
        if deviation_x > 0:
            keyboard.press(Keycode.KEYPAD_PLUS)
            print(pot_value_x)
        else:
            keyboard.press(Keycode.KEYPAD_MINUS)
            print(pot_value_x)
    else:
        keyboard.release(Keycode.KEYPAD_PLUS)
        keyboard.release(Keycode.KEYPAD_MINUS)

    print(pot_value_y)

    if abs(deviation_y) > neutral_zone:
        
        if deviation_y > 0:
            keyboard.press(Keycode.SHIFT)
            mouse.press(Mouse.MIDDLE_BUTTON)
            mouse.move(x=10)
            keyboard.release(Keycode.SHIFT)
            print(pot_value_x)
        else:
            keyboard.press(Keycode.SHIFT)
            mouse.press(Mouse.MIDDLE_BUTTON)
            mouse.move(x=-10)
            keyboard.release(Keycode.SHIFT)
            print(pot_value_x)

        mouse.release(Mouse.MIDDLE_BUTTON)
        keyboard.release(Keycode.SHIFT)

    print(pot_value_z)

    if abs(deviation_z) > neutral_zone:
        
        if deviation_z > 0:
            keyboard.press(Keycode.SHIFT)
            mouse.press(Mouse.MIDDLE_BUTTON)
            mouse.move(y=10)
            keyboard.release(Keycode.SHIFT)
            print(pot_value_y)
        else:
            keyboard.press(Keycode.SHIFT)
            mouse.press(Mouse.MIDDLE_BUTTON)
            mouse.move(y=-10)
            keyboard.release(Keycode.SHIFT)
            print(pot_value_y)

        mouse.release(Mouse.MIDDLE_BUTTON)
        keyboard.release(Keycode.SHIFT)
 
    time.sleep(0.001)
